@@ -17,7 +17,7 @@ class PraatLoader:
         self.script_dir = os.path.join(os.path.dirname(praatpath),'praatScripts')
         self.praat = praatpath
         self.init_scripts()
-        if debug:
+        if self.debug:
             self.initlog()
 
     def init_scripts(self):
@@ -54,18 +54,16 @@ class PraatLoader:
         out = self.run_script('waveformPic.praat',[filename,numbounds,boundaries])
 
     def run_script(self,name,args):
-        if debug:
+        if self.debug:
             updatelog('%s' % name)
         com = [self.praat, os.path.join(self.script_dir,name)] + map(str,args)
-        if debug:
+        if self.debug:
             updatelog('%s' % str(com))
         p = subprocess.Popen(com,stdout=subprocess.PIPE,stderr=subprocess.PIPE,stdin=subprocess.PIPE)
         stdout, stderr = p.communicate()
-        if debug:
+        if self.debug:
             updatelog('stdout: %s' % str(stdout))
             updatelog('stderr: %s' % str(stderr))
-        if stderr != '':
-            print stderr
         return stdout
 
 
